API Documentation
=================

Atom
^^^^

.. autoclass:: udkm1Dsim.Atom
    :members:

AtomMixed
^^^^^^^^^

.. autoclass:: udkm1Dsim.AtomMixed
    :members:
    
UnitCell
^^^^^^^^

.. autoclass:: udkm1Dsim.UnitCell
    :members:

Structure
^^^^^^^^^

.. autoclass:: udkm1Dsim.Structure
    :members:

Simulation
^^^^^^^^^^

.. autoclass:: udkm1Dsim.Simulation
    :members:

Xray
^^^^

.. autoclass:: udkm1Dsim.Xray
    :members:

XrayKin
^^^^^^^

.. autoclass:: udkm1Dsim.XrayKin
    :members:

XrayDyn
^^^^^^^

.. autoclass:: udkm1Dsim.XrayDyn
    :members:

XrayDynMag
^^^^^^^^^^

.. autoclass:: udkm1Dsim.XrayDynMag
    :members: